@@ -515,6 +515,10 @@ function makeConfig(opts) {
   confNum += 1;
   var icons = {'Path':'folder-o', 'Port':'minus-square-o', 'Variable':'file-text-o', 'Label':'tags', 'Device':'play-circle-o'};
   var newConfig = $("#templateDisplayConfig").html();
+  var popout = '';
+  if (opts.Type == "Path") {
+    popout = "<a class='view dfm-popout hand' onclick='openFileManagerFromInput(this)' title=\"_(Browse)_\"><i class=\"icon-u-tab\"></i></a>";
+  }
   newConfig =  newConfig.format(
     stripTags(opts.Name),
     opts.Target,
@@ -529,7 +533,8 @@ function makeConfig(opts) {
     opts.Buttons,
     opts.Required=='true' ? 'required' : '',
     sprintf('Container %s',opts.Type),
-    icons[opts.Type] || 'question'
+    icons[opts.Type] || 'question',
+    popout
   );
   newConfig = "<div id='ConfigNum"+opts.Number+"' class='config_"+opts.Display+"'' >"+newConfig+"</div>";
   newConfig = $($.parseHTML(newConfig));
@@ -820,7 +825,7 @@ function loadTemplate(el) {
 
 function rmTemplate(tmpl) {
   var name = tmpl.split(/[\/]+/).pop();
-  swal({title:"_(Are you sure?)_",text:"_(Remove template)_: "+name,type:"warning",html:true,showCancelButton:true,confirmButtonText:"_(Proceed)_",cancelButtonText:"_(Cancel)_"},function(){$("#rmTemplate").val(tmpl);$("#formTemplate1").submit();});
+  swal({title:"_(Are you sure)_?",text:"_(Remove template)_: "+name,type:"warning",html:true,showCancelButton:true,confirmButtonText:"_(Proceed)_",cancelButtonText:"_(Cancel)_"},function(){$("#rmTemplate").val(tmpl);$("#formTemplate1").submit();});
 }
 
 function openFileBrowser(el, top, root, filter, on_folders, on_files, close_on_select) {
@@ -829,12 +834,16 @@ function openFileBrowser(el, top, root, filter, on_folders, on_files, close_on_s
   if (!filter && !on_files) filter = 'HIDE_FILES_FILTER';
   if (!root.trim()) {root = "/mnt/user/"; top = "/mnt/";}
   p = $(el);
+  ensureFileManagerPopout(p);
+  updatePopoutState(p);
+  var popout = p.siblings('.dfm-popout');
+  var insertAfter = popout.length ? popout : p;
   // Skip if fileTree is already open
-  if (p.next().hasClass('fileTree')) return null;
+  if (p.siblings('.fileTree').length) return null;
   // create a random id
   var r = Math.floor((Math.random()*10000)+1);
   // Add a new span and load fileTree
-  p.after("<span id='fileTree"+r+"' class='textarea fileTree'></span>");
+  insertAfter.after("<span id='fileTree"+r+"' class='textarea fileTree'></span>");
   var ft = $('#fileTree'+r);
   ft.fileTree({top:top, root:root, filter:filter, allowBrowsing:true},
     function(file){if(on_files){p.val(file);p.trigger('change');if(close_on_select){ft.slideUp('fast',function(){ft.remove();});}}},
@@ -850,6 +859,42 @@ function openFileBrowser(el, top, root, filter, on_folders, on_files, close_on_s
   ft.slideDown('fast');
 }
 
+function openFileManagerPath(path) {
+  var trimmed = (path || '').trim();
+  if (!trimmed.length) return;
+  if (trimmed.slice(-1) !== '/') {
+    var lastSlash = trimmed.lastIndexOf('/');
+    if (lastSlash > 0) {
+      var tail = trimmed.slice(lastSlash + 1);
+      if (tail.indexOf('.') !== -1) {
+        trimmed = trimmed.slice(0, lastSlash + 1);
+      }
+    }
+  }
+  window.open('/Main/Browse?dir=' + encodeURIComponent(trimmed), '_blank', 'noopener');
+}
+
+function openFileManagerFromInput(el) {
+  var input = $(el).siblings('input[type="text"]').first();
+  if (!input.length) {
+    input = $(el).closest('span').find('input[type="text"]').first();
+  }
+  openFileManagerPath(input.val());
+}
+
+function ensureFileManagerPopout(input) {
+  $(input).addClass('dfm-popout-target');
+  if ($(input).siblings('.dfm-popout').length) return;
+  $(input).after('<a class="view dfm-popout hand" onclick="openFileManagerFromInput(this)" title="_(Browse)_"><i class="icon-u-tab"></i></a>');
+}
+
+function updatePopoutState(input) {
+  var value = $(input).val() || '';
+  var hasValue = value.trim().length > 0;
+  $(input).toggleClass('dfm-popout-target-active', hasValue);
+  $(input).siblings('.dfm-popout').toggle(hasValue);
+}
+
 function resetField(el) {
   var target = $(el).prev();
   reset = target.attr("default");
@@ -864,6 +909,14 @@ function prepareCategory() {
 }
 
 $(function() {
+  $('input[name="confValue[]"]').each(function() {
+    if ($(this).siblings('.dfm-popout').length) {
+      $(this).addClass('dfm-popout-target').on('input change', function() {
+        updatePopoutState(this);
+      });
+      updatePopoutState(this);
+    }
+  });
   var ctrl = "<span class='status'><input type='checkbox' class='advancedview'></span>";
 <?if ($tabbed):?>
   $('.tabs').append(ctrl);
@@ -1539,6 +1592,7 @@ _(Password Mask)_:
 : <span class="flex flex-col gap-4">
     <span class="flex flex-row flex-wrap items-center gap-4 buttons-no-margin">
       <input type="text" class="setting_input" name="confValue[]" default="{2}" value="{9}" autocomplete="off" spellcheck="false" {11}>
+      {14}
       {10}
     </span>
     <span class="boxed">
@@ -1932,4 +1986,3 @@ if (window.location.href.indexOf("/Apps/") > 0  && <? if (is_file($xmlTemplate))
 }
 </script>
 <?END:?>
-
